@@ -1,20 +1,26 @@
 # -*- coding: utf-8 -*-
-from django.test import TestCase
-from vkontakte_places.models import City, Country
-from models import User, USER_PHOTO_DEACTIVATED_URL, USER_NO_PHOTO_URL, USERS_INFO_TIMEOUT_DAYS
-from factories import UserFactory
 from datetime import datetime, timedelta
-import simplejson as json
+
+from django.test import TestCase
+from django.utils import timezone
 import mock
+import simplejson as json
+from vkontakte_places.models import City, Country
+
+from .factories import UserFactory
+from .models import User, USER_PHOTO_DEACTIVATED_URL, USER_NO_PHOTO_URL, USERS_INFO_TIMEOUT_DAYS
 
 USER_ID = 1
 USER_SCREEN_NAME = 'durov'
 
+
 def user_fetch_mock(ids, **kwargs):
-    users = [User.objects.get(remote_id=id) if User.objects.filter(remote_id=id).count() == 1 else UserFactory(remote_id=id) for id in ids]
+    users = [User.objects.get(remote_id=id) if User.objects.filter(
+        remote_id=id).count() == 1 else UserFactory(remote_id=id) for id in ids]
     ids = [user.pk for user in users]
     return User.objects.filter(pk__in=ids)
 
+
 class VkontakteUsersTest(TestCase):
 
     def test_refresh_user(self):
@@ -39,7 +45,7 @@ class VkontakteUsersTest(TestCase):
 #
 #        users = User.remote.fetch(ids=[1,6])
 #
-#        self.assertEqual(instance.relatives.count(), 1) # fix it, design decision needed
+# self.assertEqual(instance.relatives.count(), 1) # fix it, design decision needed
 #        self.assertEqual(instance.relatives.all()[0], users[1])
 
     def test_fetch_user_friends(self):
@@ -50,14 +56,14 @@ class VkontakteUsersTest(TestCase):
 
         users = user.fetch_friends()
 
-        self.assertTrue(User.objects.count() > 100)
+        self.assertGreater(User.objects.count(), 100)
         self.assertEqual(users.count(), User.objects.count() - 1)
         self.assertEqual(user.friends_users.count(), User.objects.count() - 1)
 
         User.objects.filter(pk__gt=100).delete()
 
-        self.assertTrue(user.friends_users.count() > 10)
-        self.assertTrue(user.friends_users.count() < 20)
+        self.assertGreater(user.friends_users.count(), 10)
+        self.assertLess(user.friends_users.count(), 20)
 
         users_existed = user.fetch_friends(only_existing_users=True)
 
@@ -67,7 +73,7 @@ class VkontakteUsersTest(TestCase):
     def test_fetch_user(self):
 
         self.assertEqual(User.objects.count(), 0)
-        users = User.remote.fetch(ids=[1,2])
+        users = User.remote.fetch(ids=[1, 2])
         self.assertEqual(len(users), 2)
         self.assertEqual(User.objects.count(), 2)
 
@@ -84,21 +90,21 @@ class VkontakteUsersTest(TestCase):
 
         # test counters
         instance.update_counters()
-        self.assertTrue(instance.followers > 0)
-        self.assertTrue(instance.notes > 0)
-        self.assertTrue(instance.sum_counters > 0)
-        self.assertTrue(instance.counters_updated is not None)
+        self.assertGreater(instance.followers, 0)
+        self.assertGreater(instance.notes, 0)
+        self.assertGreater(instance.sum_counters, 0)
+        self.assertNotEqual(instance.counters_updated, None)
 
         # fetch another time
-        users = User.remote.fetch(ids=[1,2])
+        users = User.remote.fetch(ids=[1, 2])
         self.assertEqual(User.objects.count(), 2)
 
         instance = users[0]
 
         # test for keeping old counters
-        self.assertTrue(instance.sum_counters > 0)
-        self.assertTrue(instance.followers > 0)
-        self.assertTrue(instance.counters_updated is not None)
+        self.assertGreater(instance.sum_counters, 0)
+        self.assertGreater(instance.followers, 0)
+        self.assertNotEqual(instance.counters_updated, None)
 
     @mock.patch('vkontakte_api.models.VkontakteManager.fetch', side_effect=user_fetch_mock)
     def test_fetch_users_more_than_1000(self, fetch):
@@ -119,14 +125,15 @@ class VkontakteUsersTest(TestCase):
         self.assertEqual(len(fetch.mock_calls[0].call_list()[0][2]['ids']), 1500)
 
         # make all users fresh
-        User.objects.all().update(fetched=datetime.now())
+        User.objects.all().update(fetched=timezone.now())
         # make 500 of them expired
-        User.objects.filter(remote_id__lt=500).update(fetched=datetime.now() - timedelta(USERS_INFO_TIMEOUT_DAYS + 1))
+        User.objects.filter(remote_id__lt=500).update(fetched=timezone.now() - timedelta(USERS_INFO_TIMEOUT_DAYS + 1))
 
         users_new = User.remote.fetch(ids=range(100, 2200), only_expired=True)
 
         self.assertEqual(users_new.count(), 2100)
-        self.assertEqual(len(fetch.mock_calls[1].call_list()[0][2]['ids']), 1100)  # (500 - 100) + (2200 - 1500), expired + new
+        # (500 - 100) + (2200 - 1500), expired + new
+        self.assertEqual(len(fetch.mock_calls[1].call_list()[0][2]['ids']), 1100)
 
     def test_parse_user(self):
 
@@ -202,4 +209,4 @@ class VkontakteUsersTest(TestCase):
         User.objects.create(remote_id=182224356, screen_name='mikhailserzhantov', sex=0)
 
         self.assertEqual(User.remote.get_by_slug('mikhailserzhantov').remote_id, 182224356)
-        self.assertEqual(User.objects.deactivated().count(), 2)
\ No newline at end of file
+#        self.assertEqual(User.objects.deactivated().count(), 2) deactivated users were deleted completely
